==> dianara_1.1.orig.tar.gz: dianara-v1.1/src/filtereditor.h <==
/*
 *   This file is part of Dianara
 *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef FILTEREDITOR_H
#define FILTEREDITOR_H

#include <QWidget>
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QGroupBox>
#include <QIcon>
#include <QLabel>
#include <QComboBox>
#include <QLineEdit>
#include <QPushButton>
#include <QListWidget>
#include <QVariantList>
#include <QVariantMap>
#include <QSettings>

#include <QDebug>

#include "pumpcontroller.h"

class FilterEditor : public QWidget
{
    Q_OBJECT

public:
    explicit FilterEditor(PumpController *pumpController,
                          QWidget *parent = 0);
    ~FilterEditor();

    void loadFilters();

signals:

public slots:
    void addFilter();
    void removeFilter();

    void saveFilters();

private:
    QVBoxLayout *mainLayout;
    QHBoxLayout *topLayout;
    QGroupBox *newFilterGroupBox;
    QVBoxLayout *middleLayout;
    QGroupBox *currentFiltersGroupBox;
    QHBoxLayout *bottomLayout;


    QLabel *explanationLabel;

    QComboBox *filterTypeComboBox;
    QLineEdit *filterWordsLineEdit;
    QPushButton *addFilterButton;

    QListWidget *currentFiltersListWidget;
    QPushButton *removeFilterButton;

    QPushButton *saveButton;
    QPushButton *cancelButton;


    QVariantList filtersList;

    PumpController *pController;
};

#endif // FILTEREDITOR_H

==> dianara_1.2.3.orig.tar.gz: dianara-v1.2.3/src/filtereditor.h <==
/*
 *   This file is part of Dianara
 *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef FILTEREDITOR_H
#define FILTEREDITOR_H

#include <QWidget>
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QGroupBox>
#include <QIcon>
#include <QLabel>
#include <QComboBox>
#include <QLineEdit>
#include <QPushButton>
#include <QListWidget>
#include <QVariantList>
#include <QVariantMap>
#include <QSettings>
#include <QAction>

#include <QDebug>

#include "filterchecker.h"

class FilterEditor : public QWidget
{
    Q_OBJECT

public:
    explicit FilterEditor(FilterChecker *filterChecker,
                          QWidget *parent = 0);
    ~FilterEditor();

    void loadFilters();

signals:

public slots:
    void addFilter();
    void removeFilter();

    void saveFilters();

private:
    QVBoxLayout *mainLayout;
    QHBoxLayout *topLayout;
    QGroupBox *newFilterGroupBox;
    QVBoxLayout *middleLayout;
    QGroupBox *currentFiltersGroupBox;
    QHBoxLayout *bottomLayout;


    QAction *closeAction;

    QLabel *explanationLabel;

    QComboBox *actionTypeComboBox;
    QComboBox *filterTypeComboBox;
    QLineEdit *filterWordsLineEdit;
    QPushButton *addFilterButton;

    QListWidget *currentFiltersListWidget;
    QPushButton *removeFilterButton;

    QPushButton *saveButton;
    QPushButton *cancelButton;

    QString ruleString;
    QVariantList filtersList;

    FilterChecker *fChecker;
};

#endif // FILTEREDITOR_H
